import { Column, Entity, ManyToOne, OneToMany, PrimaryGeneratedColumn } from 'typeorm';
import { Build } from './Build.entity';
import { Index } from 'typeorm';
import { TimeBase } from './TimeBase.entity';
import { ArchiveFile } from './ArchiveFile.entity';

export enum ArchiveType {
  Full = 'full',
  Update = 'update',
  Part = 'part',
}

@Entity()
export class Archive extends TimeBase {
  @PrimaryGeneratedColumn({ type: 'int8' })
  id: number;

  //@Column('varchar', { length: 256, array: true })
  //files: string[];

  @OneToMany(() => ArchiveFile, (file) => file.archive, { cascade: true })
  containingFiles: ArchiveFile[];

  @Index()
  @Column('varchar', { length: 128 })
  path: string;

  @Column('varchar', { length: 64, nullable: true })
  hash: string;

  @Column('int', { unsigned: true })
  size: number;

  @ManyToOne((type) => Build, (build) => build.archives, { onDelete: 'CASCADE' })
  build: Build;

  @Index()
  @Column({ type: 'enum', enum: ArchiveType })
  role: ArchiveType;

  get archiveFullPath() {
    return `${this.path}.tar.zst`;
  }

  get paramSize() {
    return 5 + (this.containingFiles ? this.containingFiles.length : 0);
  }

  toMetalinkView() {
    return {
      name: this.archiveFullPath,
    };
  }
}
